@@ -1,7 +1,7 @@
 // synthv1_lv2.cpp
 //
 /****************************************************************************
-   Copyright (C) 2012-2023, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2012-2024, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -26,18 +26,28 @@
 #include "synthv1_programs.h"
 #include "synthv1_controls.h"
 
+#ifdef CONFIG_LV2_OLD_HEADERS
 #include "lv2/lv2plug.in/ns/ext/midi/midi.h"
 #include "lv2/lv2plug.in/ns/ext/time/time.h"
 #include "lv2/lv2plug.in/ns/ext/atom/util.h"
-
 #include "lv2/lv2plug.in/ns/ext/state/state.h"
-
 #include "lv2/lv2plug.in/ns/ext/options/options.h"
 #include "lv2/lv2plug.in/ns/ext/buf-size/buf-size.h"
-
 #ifdef CONFIG_LV2_PATCH
 #include "lv2/lv2plug.in/ns/ext/patch/patch.h"
 #endif
+#else
+#include "lv2/midi/midi.h"
+#include "lv2/time/time.h"
+#include "lv2/atom/util.h"
+#include "lv2/state/state.h"
+#include "lv2/options/options.h"
+#include "lv2/buf-size/buf-size.h"
+#ifdef CONFIG_LV2_PATCH
+#include "lv2/patch/patch.h"
+#endif
+#endif
+
 
 #ifndef CONFIG_LV2_ATOM_FORGE_OBJECT
 #define lv2_atom_forge_object(forge, frame, id, otype) \
@@ -93,6 +103,10 @@ synthv1_lv2::synthv1_lv2 (
 	m_schedule = nullptr;
 	m_ndelta   = 0;
 
+#ifdef CONFIG_LV2_PORT_CHANGE_REQUEST
+	m_port_change_request = nullptr;
+#endif
+
 	const LV2_Options_Option *host_options = nullptr;
 
 	for (int i = 0; host_features && host_features[i]; ++i) {
@@ -164,6 +178,11 @@ synthv1_lv2::synthv1_lv2 (
 		else
 		if (::strcmp(host_feature->URI, LV2_OPTIONS__options) == 0)
 			host_options = (const LV2_Options_Option *) host_feature->data;
+	#ifdef CONFIG_LV2_PORT_CHANGE_REQUEST
+		else
+		if (::strcmp(host_feature->URI, LV2_CONTROL_INPUT_PORT_CHANGE_REQUEST_URI) == 0)
+			m_port_change_request = (LV2_ControlInputPort_Change_Request *) host_feature->data;
+	#endif
 	}
 
 	uint32_t buffer_size = 1024; // maybe some safe default?
@@ -393,7 +412,7 @@ void synthv1_lv2::qapp_instantiate (void)
 {
 	if (qApp == nullptr && g_qapp_instance == nullptr) {
 		static int s_argc = 1;
-		static const char *s_argv[] = { SYNTHV1_TITLE, nullptr };
+		static const char *s_argv[] = { PROJECT_NAME, nullptr };
 	#if defined(WIN32) || defined(_WIN32) || defined(__WIN32)
 		::_putenv_s("QT_NO_GLIB", "1"); // Avoid glib event-loop...
 	#else
@@ -462,7 +481,7 @@ static LV2_State_Status synthv1_lv2_state_save ( LV2_Handle instance,
 	flags |= (LV2_STATE_IS_POD | LV2_STATE_IS_PORTABLE);
 #endif
 
-	QDomDocument doc(SYNTHV1_TITLE);
+	QDomDocument doc(PROJECT_NAME);
 	QDomElement eState = doc.createElement("state");
 
 	QDomElement eTuning = doc.createElement("tuning");
@@ -516,7 +535,7 @@ static LV2_State_Status synthv1_lv2_state_restore ( LV2_Handle instance,
 	if (value == nullptr)
 		return LV2_STATE_ERR_UNKNOWN;
 
-	QDomDocument doc(SYNTHV1_TITLE);
+	QDomDocument doc(PROJECT_NAME);
 	if (doc.setContent(QByteArray(value, size))) {
 		QDomElement eState = doc.documentElement();
 		if (eState.tagName() == "state") {
@@ -599,6 +618,11 @@ void synthv1_lv2::updatePreset ( bool /*bDirty*/ )
 
 void synthv1_lv2::updateParam ( synthv1::ParamIndex index )
 {
+#ifdef CONFIG_LV2_PORT_CHANGE_REQUEST
+	if (port_change_request(index))
+		return;
+#endif
+
 #ifdef CONFIG_LV2_PORT_EVENT
 	if (m_schedule) {
 		synthv1_lv2_worker_message mesg;
@@ -608,14 +632,17 @@ void synthv1_lv2::updateParam ( synthv1::ParamIndex index )
 		m_schedule->schedule_work(
 			m_schedule->handle, sizeof(mesg), &mesg);
 	}
-#else
-	(void) index; // STFU dang compiler!
 #endif
 }
 
 
 void synthv1_lv2::updateParams (void)
 {
+#ifdef CONFIG_LV2_PORT_CHANGE_REQUEST
+	if (port_change_requests())
+		return;
+#endif
+
 #ifdef CONFIG_LV2_PORT_EVENT
 	if (m_schedule) {
 		synthv1_lv2_worker_message mesg;
@@ -806,6 +833,48 @@ bool synthv1_lv2::port_events (void)
 #endif	// CONFIG_LV2_PORT_EVENT
 
 
+#ifdef CONFIG_LV2_PORT_CHANGE_REQUEST
+
+bool synthv1_lv2::port_change_request ( synthv1::ParamIndex index )
+{
+	if (m_port_change_request == nullptr)
+		return false;
+	if (m_port_change_request->handle == nullptr)
+		return false;
+	if (m_port_change_request->request_change == nullptr)
+		return false;
+
+	return m_port_change_request->request_change(
+		m_port_change_request->handle,
+		uint32_t(ParamBase + index),
+		synthv1::paramValue(index))
+		== LV2_CONTROL_INPUT_PORT_CHANGE_SUCCESS;
+}
+
+
+bool synthv1_lv2::port_change_requests (void)
+{
+	if (m_port_change_request == nullptr)
+		return false;
+	if (m_port_change_request->handle == nullptr)
+		return false;
+	if (m_port_change_request->request_change == nullptr)
+		return false;
+
+	for (uint32_t i = 0; i < synthv1::NUM_PARAMS; ++i) {
+		synthv1::ParamIndex index = synthv1::ParamIndex(i);
+		m_port_change_request->request_change(
+			m_port_change_request->handle,
+			uint32_t(ParamBase + index),
+			synthv1::paramValue(index));
+	}
+
+	return true;
+}
+
+#endif	// CONFIG_LV2_PORT_CHANGE_REQUEST
+
+
 //-------------------------------------------------------------------------
 // synthv1_lv2 - LV2 desc.
 //
