@@ -166,8 +166,11 @@ synthv1widget_palette::~synthv1widget_palette (void)
 void synthv1widget_palette::setPalette ( const QPalette& pal )
 {
 	m_palette = pal;
-
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+	const uint mask = pal.resolveMask();
+#else
 	const uint mask = pal.resolve();
+#endif
 	for (int i = 0; g_colorRoles[i].key; ++i) {
 		if ((mask & (1 << i)) == 0) {
 			const QPalette::ColorRole cr = QPalette::ColorRole(i);
@@ -179,7 +182,11 @@ void synthv1widget_palette::setPalette ( const QPalette& pal )
 				m_parentPalette.brush(QPalette::Disabled, cr));
 		}
 	}
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+	m_palette.setResolveMask(mask);
+#else
 	m_palette.resolve(mask);
+#endif
 
 	updateGenerateButton();
 
@@ -334,7 +341,11 @@ void synthv1widget_palette::importButtonClicked (void)
 		if (!name.isEmpty()) {
 			QPalette pal;
 			int result = 0;
+		#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+			uint mask = pal.resolveMask();
+		#else
 			uint mask = pal.resolve();
+		#endif
 			settings.beginGroup(name + '/');
 			QStringListIterator iter(settings.childKeys());
 			while (iter.hasNext()) {
@@ -351,7 +362,11 @@ void synthv1widget_palette::importButtonClicked (void)
 					++result;
 				}
 			}
+		#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+			pal.setResolveMask(mask);
+		#else
 			pal.resolve(mask);
+		#endif
 			settings.endGroup();
 			if (result > 0) {
 				saveNamedPalette(name, pal);
@@ -938,7 +953,11 @@ QVariant synthv1widget_palette::PaletteModel::data ( const QModelIndex& index, i
 		if (role == Qt::DisplayRole)
 			return m_roleNames.value(QPalette::ColorRole(index.row()));
 		if (role == Qt::EditRole) {
+		#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+			const uint mask = m_palette.resolveMask();
+		#else
 			const uint mask = m_palette.resolve();
+		#endif
 			return bool(mask & (1 << index.row()));
 		}
 	}
@@ -1001,7 +1020,11 @@ bool synthv1widget_palette::PaletteModel::setData (
 	}
 
 	if (index.column() == 0 && role == Qt::EditRole) {
+	#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+		uint mask = m_palette.resolveMask();
+	#else
 		uint mask = m_palette.resolve();
+	#endif
 		const bool masked = value.value<bool>();
 		const int i = index.row();
 		if (masked) {
@@ -1016,7 +1039,11 @@ bool synthv1widget_palette::PaletteModel::setData (
 				m_parentPalette.brush(QPalette::Disabled, cr));
 			mask &= ~(1 << i);
 		}
+	#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+		m_palette.setResolveMask(mask);
+	#else
 		m_palette.resolve(mask);
+	#endif
 		emit paletteChanged(m_palette);
 		const QModelIndex& index_end = PaletteModel::index(i, 3);
 		emit dataChanged(index, index_end);
